# GritBot

This is the original GritBot software which inspired Outlier Tree. Source code is taken from RuleQuest's official webpage and has not undergone any modifications in here. This code is not included in the R or Python packages, and has no available wrappers at the time of writing. The Python package however offers some functionality for generating data files for GritBot. 

This is the GPL Linux version (will not work on Windows due to OS time headers - but that part can be safely removed). Compile with `make`.
